//global variables

var map; //scaleRaphael map object
var mapBg; //SVG background element
var $mw; //map wrapper

var enableDrag = false;
var mapDragged = 0; //distinguish dragging from clicking

var mouseDragStartX = 0; //starting cursor position for drag
var mouseDragStartY = 0;

var gMouseX = 0; //global current mouse coordinates
var gMouseY = 0;

var mapScale = 1; //global map scale factor

var isMouseLabelVisible = 0;

var distanceCalc = { 'state': 0, 'x': 0, 'y': 0 }; //state: 0: disabled, 1: enabled (waiting for X), 2: waiting for Y
var headingCalc = { 'state': 0, 'x': 0, 'y': 0 }; //state: 0: disabled, 1: enabled (waiting for X), 2: waiting for Y

var objects; //global object storing variable to speed up svg - heterogeneous array
var objects_count;
var obj_symbol_data;

var runwayWidth; //values fetched from DB
var maptextOffset;

var zoomToFitScale;

var northestObjY;

var ctransform; //coordinate transformation functions, defined in "functions.js"

var $coordDiv;
var freezeInGameCoordinates = false;

//----------------------------------------
			
$(document).ready(function(){

	$mw = $('#mapWrapper');
	objects = new Array();
	objects_count = 0;
	obj_symbol_data = new Array();
	$coordDiv = $('#coordinateDiv');
	
	svgsetup(); //call php generated JS file
	ddMenu_events_init(); //drop-down menu events
	
	scaleMap(1); //scale to fit window	
	
	//--------- event setup ------------
	
	$mw
		.on('mousedown', function(e){
		
			mouseDragStartX = e.pageX;
			mouseDragStartY = e.pageY;
			enableDrag = true;
			mapDragged = 0;
			
			ddMenu_hideExcept($('#ddButton_search'));
			
			if (e.preventDefault) e.preventDefault();
			
		})
		.on('mousemove', function(e){
		
			//display IG coords on menubar
			if (!freezeInGameCoordinates)
				$coordDiv.html( (40*(gMouseX - $mw.offset().left)/mapScale - 20000).toFixed(4) + ', ' +
					(-40*(gMouseY - $mw.offset().top)/mapScale + 20000).toFixed(4) );
			
			if (enableDrag){
				dragMap(e);
				mapDragged = 1;
				mouseDragStartX = e.pageX;
				mouseDragStartY = e.pageY;
			} //if
			
		})
		.on('mousewheel', function(e, delta){
		
			if (delta == 1) scaleMap(2);
			if (delta == -1) scaleMap(0.5);
			
		})
		
		//--------- DELEGATED MAP EVENTS ------------
		
		.on('click', function(e){ //if a map object has been clicked
			
			var $target = $(e.target);
			var oID;
			
			if (e.target.nodeName == 'tspan') $target = $target.parent();			
			
			if (typeof( $target.attr('class') ) == 'undefined'){
			
				//do nothing
			
			} else if ( $target.attr('class').match(/.*t30.*/) != null ){ //if you click on a road
				
				ajax_getRoadDetails( $target.data("objectid") );
				
			} else {
			
				oID = $target.data('objectid');			
				if (mapDragged == 0 && typeof(oID) != 'undefined') objectClickHandler(oID);
			
			} //else
			
			if (e.preventDefault) e.preventDefault();
		})
			
		.on('mouseover', function(e){ //highlight maptext of a given object
			
			var $target = $(e.target);
			
			if (e.target.nodeName == 'tspan') $target = $target.parent();
			
			if ($target.hasClass('mapText')) return;
			if (typeof( $target.attr('class') ) == 'undefined') return; //
			
			if ($target.attr('class').match(/.*t30.*/) != null) return; //hovered over a road
			
			var txtObject = $('#mapText_' + $target.data('objectid') );
			
			if (txtObject.css('display') == 'none')
				displayMouseLabel(txtObject.html());
			else
				setLabelHighlight(txtObject, true);
		})
			
		.on('mouseout', function(e){ //disable highlight
			
			var $target = $(e.target);
			if (e.target.nodeName == 'tspan') $target = $target.parent();
			if ($target.hasClass('mapText')) return;
						
			setLabelHighlight( $('#mapText_' + $target.data('objectid') ) , false);			
			hideMouseLabel();
		});
			
			
		
				
	
	
	





	
	//--------- WINDOW EVENTS -----------	
			
	$(window).on('mouseup', function(){
		enableDrag = false;
	})
	
	.on('keypress', function(e){ //toggle coordinate freezing
		if (e.which = 'f')
			freezeInGameCoordinates ^= 1;
	})
	
	.load(function(){
		setLoadingIcon(false);
		$('input').attr('autocomplete', 'off'); //disable autocomplete for all inputs		
	})
	
	.on('mousemove', function(e){
	
		gMouseX = e.pageX;
		gMouseY = e.pageY;
		
		
		if (isMouseLabelVisible)	//move mouse label
			$('#mouseLabel').css({
				'left': (gMouseX + 15) + 'px',
				'top': (gMouseY + 15) + 'px'
			});
	});
	
	
	
	//------- ETC ----------
	
	$('#errorMessageClose').on('click', function(){
		$('#errorMessageWrapper').fadeOut(300);
	});
	
	
}); //ready()